==> buffybox_3.2.0+dfsg.orig.tar.xz: buffybox-3.2.0/lvgl/tests/test_images/stride_align64/LZ4/test_A2_LZ4_align64.c <==

#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif


#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_IMG_DUST
#define LV_ATTRIBUTE_IMG_DUST
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_IMG_DUST
uint8_t test_A2_LZ4_align64_map[] = {

    0x02,0x00,0x00,0x00,0x19,0x02,0x00,0x00,0x80,0x07,0x00,0x00,0x1c,0xff,0x01,0x00,
    0x29,0xfc,0x00,0x01,0x00,0x19,0xc0,0x0e,0x00,0x41,0x00,0x00,0x00,0x0c,0x06,0x00,
    0x05,0x02,0x00,0x0f,0x20,0x00,0x0d,0x17,0xc3,0x53,0x00,0x10,0x03,0x6d,0x00,0x0b,
    0x40,0x00,0x02,0x20,0x00,0xbf,0x02,0xff,0x80,0x00,0x00,0x00,0x03,0x00,0x00,0x00,
    0x03,0x20,0x00,0x02,0xbf,0x2f,0xff,0xf8,0x00,0x07,0xd0,0x03,0x3f,0xff,0xff,0xf3,
    0x20,0x00,0x02,0xbf,0xbf,0xff,0xfe,0x00,0x0f,0xf0,0x03,0x30,0x00,0x00,0x33,0x20,
    0x00,0x01,0xbf,0x02,0xff,0xff,0xff,0x80,0x0f,0xf0,0x03,0x33,0xff,0xff,0x20,0x00,
    0x02,0xbf,0x03,0xff,0xff,0xff,0xc0,0x07,0xd0,0x03,0x33,0x00,0x03,0x20,0x00,0x02,
    0xbf,0x0b,0xff,0xff,0xff,0xe0,0x00,0x00,0x03,0x33,0x3f,0xf3,0x20,0x00,0x02,0xbf,
    0x0f,0xff,0xff,0xff,0xf0,0x00,0x00,0x03,0x33,0x30,0x33,0x20,0x00,0x07,0x5f,0x1b,
    0xe4,0x03,0x33,0x33,0x20,0x00,0x08,0x2f,0x7f,0xfd,0x40,0x00,0x0b,0x2f,0xbf,0xfe,
    0x80,0x00,0x06,0x01,0xa0,0x00,0x2f,0xff,0xff,0xc0,0x00,0x06,0x01,0xe0,0x00,0x2f,
    0xff,0xff,0x00,0x01,0x06,0x01,0x20,0x01,0x2f,0xbf,0xfe,0x40,0x01,0x06,0x7f,0x00,
    0xbf,0xff,0xfe,0x00,0x7f,0xfd,0x80,0x01,0x07,0x6f,0x2f,0xff,0xf8,0x00,0x1b,0xe4,
    0xc0,0x01,0x01,0x02,0x20,0x02,0x03,0xe0,0x01,0x0f,0x00,0x02,0x00,0x02,0x20,0x00,
    0x07,0x02,0x00,0x0b,0xc0,0x01,0x0f,0x20,0x00,0x12,0x17,0x3f,0xc5,0x02,0x0c,0x40,
    0x00,0x37,0x0b,0xff,0xf4,0x5e,0x00,0x0e,0x60,0x00,0x3f,0xbf,0xff,0xfe,0x20,0x00,
    0x0a,0x21,0xff,0xff,0x9c,0x02,0x05,0x02,0x00,0x0c,0x60,0x00,0x39,0xff,0x40,0xff,
    0xa4,0x00,0x0c,0x20,0x00,0x84,0xfe,0x00,0x7f,0xd0,0x00,0x01,0xbf,0x80,0x41,0x00,
    0x0c,0x20,0x00,0x66,0xbd,0x00,0x3f,0xe0,0x00,0x1f,0xa5,0x00,0x0c,0x20,0x00,0x11,
    0x00,0x20,0x00,0x15,0xeb,0x97,0x03,0x0c,0x20,0x00,0x72,0x06,0xff,0xff,0xe0,0x00,
    0x1f,0x40,0xc5,0x00,0x3c,0x33,0x0c,0x0c,0x20,0x00,0x72,0x3f,0xff,0xff,0xe0,0x00,
    0x1a,0x00,0x20,0x00,0x0f,0xc0,0x03,0x00,0xbf,0xff,0xfe,0xbf,0xe0,0x00,0x00,0x5a,
    0xfe,0x00,0x00,0x15,0x20,0x00,0x01,0xdf,0xc1,0xff,0x40,0x3f,0xe0,0x00,0x0b,0xff,
    0xfe,0x00,0x00,0xff,0xd0,0x40,0x01,0x00,0xdf,0xc2,0xff,0x00,0x3f,0xe0,0x00,0x2f,
    0xea,0xfe,0x00,0x00,0xd1,0xe0,0x80,0x00,0x00,0x11,0xc3,0x20,0x00,0x7f,0x3f,0x80,
    0xfe,0x00,0x00,0x16,0xf0,0x40,0x00,0x02,0xaf,0x41,0xff,0xe0,0x00,0x3f,0x40,0xfe,
    0x00,0x00,0xff,0x20,0x00,0x01,0xdf,0xc1,0xff,0xff,0xff,0xfd,0x00,0x3f,0xd7,0xff,
    0x00,0x01,0xe0,0xf0,0x60,0x00,0x00,0xcf,0xc0,0xff,0xff,0xbf,0xfd,0x00,0x2f,0xff,
    0xff,0xc0,0x01,0xf6,0x40,0x00,0x01,0xdf,0xc0,0x2f,0xfe,0x1f,0xfd,0x00,0x0b,0xfd,
    0x7f,0xc0,0x00,0xbe,0xf8,0x40,0x00,0x01,0x21,0x00,0x40,0xf7,0x00,0x05,0x02,0x00,
    0x0c,0x40,0x01,0x05,0x19,0x00,0x03,0x02,0x00,0x0b,0x20,0x00,0x15,0xc3,0x7b,0x02,
    0x5f,0xfe,0xaa,0xa9,0x55,0x50,0x20,0x00,0xff,0x9f,0x09,0xbc,0x03,0x0f,0xa0,0x02,
    0x00,0x0f,0x20,0x00,0x2d,0x05,0x1f,0x02,0x04,0x02,0x00,0x05,0xc9,0x03,0x60,0x00,
    0x00,0x00,0x00,0x00,0x00,

};

const lv_img_dsc_t test_A2_LZ4_align64 = {
  .header.magic = LV_IMAGE_HEADER_MAGIC,
  .header.cf = LV_COLOR_FORMAT_A2,
  .header.flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
  .header.w = 71,
  .header.h = 60,
  .header.stride = 32,
  .data_size = 549,
  .data = test_A2_LZ4_align64_map,
};

==> buffybox_3.4.2+dfsg.orig.tar.xz: buffybox-3.4.2+dfsg/lvgl/tests/test_images/stride_align64/LZ4/test_A2_LZ4_align64.c <==

#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_LVGL_H_INCLUDE_SYSTEM)
#include <lvgl.h>
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif

#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_TEST_A2_LZ4_ALIGN64
#define LV_ATTRIBUTE_TEST_A2_LZ4_ALIGN64
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_TEST_A2_LZ4_ALIGN64
uint8_t test_A2_LZ4_align64_map[] = {

    0x02,0x00,0x00,0x00,0x19,0x02,0x00,0x00,0x80,0x07,0x00,0x00,0x1c,0xff,0x01,0x00,
    0x29,0xfc,0x00,0x01,0x00,0x19,0xc0,0x0e,0x00,0x41,0x00,0x00,0x00,0x0c,0x06,0x00,
    0x05,0x02,0x00,0x0f,0x20,0x00,0x0d,0x17,0xc3,0x53,0x00,0x10,0x03,0x6d,0x00,0x0b,
    0x40,0x00,0x02,0x20,0x00,0xbf,0x02,0xff,0x80,0x00,0x00,0x00,0x03,0x00,0x00,0x00,
    0x03,0x20,0x00,0x02,0xbf,0x2f,0xff,0xf8,0x00,0x07,0xd0,0x03,0x3f,0xff,0xff,0xf3,
    0x20,0x00,0x02,0xbf,0xbf,0xff,0xfe,0x00,0x0f,0xf0,0x03,0x30,0x00,0x00,0x33,0x20,
    0x00,0x01,0xbf,0x02,0xff,0xff,0xff,0x80,0x0f,0xf0,0x03,0x33,0xff,0xff,0x20,0x00,
    0x02,0xbf,0x03,0xff,0xff,0xff,0xc0,0x07,0xd0,0x03,0x33,0x00,0x03,0x20,0x00,0x02,
    0xbf,0x0b,0xff,0xff,0xff,0xe0,0x00,0x00,0x03,0x33,0x3f,0xf3,0x20,0x00,0x02,0xbf,
    0x0f,0xff,0xff,0xff,0xf0,0x00,0x00,0x03,0x33,0x30,0x33,0x20,0x00,0x07,0x5f,0x1b,
    0xe4,0x03,0x33,0x33,0x20,0x00,0x08,0x2f,0x7f,0xfd,0x40,0x00,0x0b,0x2f,0xbf,0xfe,
    0x80,0x00,0x06,0x01,0xa0,0x00,0x2f,0xff,0xff,0xc0,0x00,0x06,0x01,0xe0,0x00,0x2f,
    0xff,0xff,0x00,0x01,0x06,0x01,0x20,0x01,0x2f,0xbf,0xfe,0x40,0x01,0x06,0x7f,0x00,
    0xbf,0xff,0xfe,0x00,0x7f,0xfd,0x80,0x01,0x07,0x6f,0x2f,0xff,0xf8,0x00,0x1b,0xe4,
    0xc0,0x01,0x01,0x02,0x20,0x02,0x03,0xe0,0x01,0x0f,0x00,0x02,0x00,0x02,0x20,0x00,
    0x07,0x02,0x00,0x0b,0xc0,0x01,0x0f,0x20,0x00,0x12,0x17,0x3f,0xc5,0x02,0x0c,0x40,
    0x00,0x37,0x0b,0xff,0xf4,0x5e,0x00,0x0e,0x60,0x00,0x3f,0xbf,0xff,0xfe,0x20,0x00,
    0x0a,0x21,0xff,0xff,0x9c,0x02,0x05,0x02,0x00,0x0c,0x60,0x00,0x39,0xff,0x40,0xff,
    0xa4,0x00,0x0c,0x20,0x00,0x84,0xfe,0x00,0x7f,0xd0,0x00,0x01,0xbf,0x80,0x41,0x00,
    0x0c,0x20,0x00,0x66,0xbd,0x00,0x3f,0xe0,0x00,0x1f,0xa5,0x00,0x0c,0x20,0x00,0x11,
    0x00,0x20,0x00,0x15,0xeb,0x97,0x03,0x0c,0x20,0x00,0x72,0x06,0xff,0xff,0xe0,0x00,
    0x1f,0x40,0xc5,0x00,0x3c,0x33,0x0c,0x0c,0x20,0x00,0x72,0x3f,0xff,0xff,0xe0,0x00,
    0x1a,0x00,0x20,0x00,0x0f,0xc0,0x03,0x00,0xbf,0xff,0xfe,0xbf,0xe0,0x00,0x00,0x5a,
    0xfe,0x00,0x00,0x15,0x20,0x00,0x01,0xdf,0xc1,0xff,0x40,0x3f,0xe0,0x00,0x0b,0xff,
    0xfe,0x00,0x00,0xff,0xd0,0x40,0x01,0x00,0xdf,0xc2,0xff,0x00,0x3f,0xe0,0x00,0x2f,
    0xea,0xfe,0x00,0x00,0xd1,0xe0,0x80,0x00,0x00,0x11,0xc3,0x20,0x00,0x7f,0x3f,0x80,
    0xfe,0x00,0x00,0x16,0xf0,0x40,0x00,0x02,0xaf,0x41,0xff,0xe0,0x00,0x3f,0x40,0xfe,
    0x00,0x00,0xff,0x20,0x00,0x01,0xdf,0xc1,0xff,0xff,0xff,0xfd,0x00,0x3f,0xd7,0xff,
    0x00,0x01,0xe0,0xf0,0x60,0x00,0x00,0xcf,0xc0,0xff,0xff,0xbf,0xfd,0x00,0x2f,0xff,
    0xff,0xc0,0x01,0xf6,0x40,0x00,0x01,0xdf,0xc0,0x2f,0xfe,0x1f,0xfd,0x00,0x0b,0xfd,
    0x7f,0xc0,0x00,0xbe,0xf8,0x40,0x00,0x01,0x21,0x00,0x40,0xf7,0x00,0x05,0x02,0x00,
    0x0c,0x40,0x01,0x05,0x19,0x00,0x03,0x02,0x00,0x0b,0x20,0x00,0x15,0xc3,0x7b,0x02,
    0x5f,0xfe,0xaa,0xa9,0x55,0x50,0x20,0x00,0xff,0x9f,0x09,0xbc,0x03,0x0f,0xa0,0x02,
    0x00,0x0f,0x20,0x00,0x2d,0x05,0x1f,0x02,0x04,0x02,0x00,0x05,0xc9,0x03,0x60,0x00,
    0x00,0x00,0x00,0x00,0x00,

};

const lv_image_dsc_t test_A2_LZ4_align64 = {
  .header = {
    .magic = LV_IMAGE_HEADER_MAGIC,
    .cf = LV_COLOR_FORMAT_A2,
    .flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
    .w = 71,
    .h = 60,
    .stride = 32,
    .reserved_2 = 0,
  },
  .data_size = sizeof(test_A2_LZ4_align64_map),
  .data = test_A2_LZ4_align64_map,
  .reserved = NULL,
};
